summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorCanop <cano.petrole@gmail.com>2023-07-02 17:22:48 +0200
committerCanop <cano.petrole@gmail.com>2023-07-02 17:22:48 +0200
commit70e0375d09b36c523cf1e54617aeebaf103ff8e1 (patch)
tree877091868a933946d21c3f7ca3d25b30b1d3367c
parentf9ad593be611e4d4ce1956523b47aa86b159f284 (diff)
lfs renamed to dysk
-rw-r--r--.gitignore1
-rw-r--r--Cargo.lock28
-rw-r--r--Cargo.toml7
-rw-r--r--README.md17
-rwxr-xr-xcompile-all-targets.sh6
-rwxr-xr-xrelease.sh10
-rw-r--r--src/args.rs2
-rw-r--r--src/col.rs2
-rw-r--r--src/cols.rs4
-rw-r--r--src/list_cols.rs8
-rw-r--r--src/main.rs2
-rw-r--r--website/README.md2
-rwxr-xr-xwebsite/deploy.sh2
-rw-r--r--website/docs/community.md10
-rw-r--r--website/docs/css/extra.css63
-rw-r--r--website/docs/filters.md8
-rw-r--r--website/docs/img/logo-lfs.pngbin445059 -> 445060 bytes
-rw-r--r--website/docs/index.md10
-rw-r--r--website/docs/install.md27
-rw-r--r--website/docs/json.md8
-rw-r--r--website/docs/table.md22
-rw-r--r--website/mkdocs.yml6
22 files changed, 144 insertions, 101 deletions
diff --git a/.gitignore b/.gitignore
index a9bf1b1..6c4984d 100644
--- a/.gitignore
+++ b/.gitignore
@@ -1,6 +1,7 @@
/target
/build
/releases
+/dysk_*.zip
/lfs_*.zip
/trav
/deploy.sh
diff --git a/Cargo.lock b/Cargo.lock
index dd347db..8b831ca 100644
--- a/Cargo.lock
+++ b/Cargo.lock
@@ -172,6 +172,20 @@ source = "registry+https://github.com/rust-lang/crates.io-index"
checksum = "fea41bba32d969b513997752735605054bc0dfa92b4c56bf1189f2e174be7a10"
[[package]]
+name = "dysk"
+version = "2.6.0"
+dependencies = [
+ "argh",
+ "bet",
+ "crossterm",
+ "file-size",
+ "lfs-core",
+ "serde",
+ "serde_json",
+ "termimad",
+]
+
+[[package]]
name = "file-size"
version = "1.0.3"
source = "registry+https://github.com/rust-lang/crates.io-index"
@@ -213,20 +227,6 @@ dependencies = [
]
[[package]]
-name = "lfs"
-version = "2.6.0"
-dependencies = [
- "argh",
- "bet",
- "crossterm",
- "file-size",
- "lfs-core",
- "serde",
- "serde_json",
- "termimad",
-]
-
-[[package]]
name = "lfs-core"
version = "0.11.1"
source = "registry+https://github.com/rust-lang/crates.io-index"
diff --git a/Cargo.toml b/Cargo.toml
index bf581c6..45aabbb 100644
--- a/Cargo.toml
+++ b/Cargo.toml
@@ -1,15 +1,18 @@
[package]
-name = "lfs"
+name = "dysk"
version = "2.6.0"
authors = ["dystroy <denys.seguret@gmail.com>"]
edition = "2021"
-keywords = ["linux", "filesystem", "fs"]
+keywords = ["linux", "filesystem", "fs", "lfs", "disk"]
license = "MIT"
categories = ["filesystem", "command-line-utilities"]
description = "give information on mounted filesystems"
repository = "https://github.com/Canop/lfs"
+homepage = "https://dystroy.org/dysk"
+documentation = "https://dystroy.org/dysk"
readme = "README.md"
rust-version = "1.59"
+exclude = ["website", "dysk*.zip"]
[dependencies]
argh = "0.1.7"
diff --git a/README.md b/README.md
index fc6374b..4740a10 100644
--- a/README.md
+++ b/README.md
@@ -1,15 +1,15 @@
-# lfs
+# dysk
[![CI][s3]][l3] [![MIT][s2]][l2] [![Latest Version][s1]][l1] [![Chat on Miaou][s4]][l4]
-[s1]: https://img.shields.io/crates/v/lfs.svg
-[l1]: https://crates.io/crates/lfs
+[s1]: https://img.shields.io/crates/v/dysk.svg
+[l1]: https://crates.io/crates/dysk
[s2]: https://img.shields.io/badge/license-MIT-blue.svg
[l2]: LICENSE
-[s3]: https://travis-ci.org/Canop/lfs.svg?branch=master
-[l3]: https://travis-ci.org/Canop/lfs
+[s3]: https://travis-ci.org/Canop/dysk.svg?branch=master
+[l3]: https://travis-ci.org/Canop/dysk
[s4]: https://miaou.dystroy.org/static/shields/room.svg
[l4]: https://miaou.dystroy.org/3768?Rust
@@ -17,11 +17,12 @@
A linux utility listing your filesystems.
-Complete documentation lives at **[https://dystroy.org/lfs](https://dystroy.org/lfs)**
+Complete documentation lives at **[https://dystroy.org/dysk](https://dystroy.org/dysk)**
-* **[Overview](https://dystroy.org/lfs/)**
-* **[Installation](https://dystroy.org/lfs/install)**
+* **[Overview](https://dystroy.org/dysk/)**
+* **[Installation](https://dystroy.org/dysk/install)**
+**Note:** dysk was previously known as lfs
### Default table
diff --git a/compile-all-targets.sh b/compile-all-targets.sh
index f3cf882..9ac2069 100755
--- a/compile-all-targets.sh
+++ b/compile-all-targets.sh
@@ -9,7 +9,7 @@ H2="\n\e[30;104m\e[1K\n\e[A" # style second header
EH="\e[00m\n\e[2K" # end header
version=$(./version.sh)
-echo -e "${H1}Compilation of all targets for lfs $version${EH}"
+echo -e "${H1}Compilation of all targets for dysk $version${EH}"
# clean previous build
rm -rf build
@@ -21,7 +21,7 @@ target="x86_64-linux"
echo -e "${H2}Compiling the linux version - $target${EH}"
cargo build --release
mkdir "build/$target/"
-cp target/release/lfs "build/$target/"
+cp target/release/dysk "build/$target/"
# build versions for other platforms using cargo cross
cross_build() {
@@ -30,7 +30,7 @@ cross_build() {
echo -e "${H2}Compiling the $name / $target version${EH}"
cross build --target "$target" --release
mkdir "build/$target"
- cp "target/$target/release/lfs" "build/$target/"
+ cp "target/$target/release/dysk" "build/$target/"
}
cross_build "Raspberry 32" "armv7-unknown-linux-gnueabihf"
cross_build "Android" "aarch64-linux-android"
diff --git a/src/args.rs b/src/args.rs
index 5091b5b..67065a2 100644
--- a/src/args.rs
+++ b/src/args.rs
@@ -13,7 +13,7 @@ use {
#[derive(FromArgs)]
/// List your filesystems.
///
-/// Documentation at https://dystroy.org/lfs
+/// Documentation at https://dystroy.org/dysk
pub struct Args {
/// print the version
#[argh(switch, short = 'v')]
diff --git a/src/col.rs b/src/col.rs
index 29af918..95ac649 100644
--- a/src/col.rs
+++ b/src/col.rs
@@ -270,7 +270,7 @@ impl fmt::Display for ParseColError {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(
f,
- "{:?} can't be parsed as a column; use 'lfs --list-cols' to see all column names",
+ "{:?} can't be parsed as a column; use 'dysk --list-cols' to see all column names",
self.raw,
)
}
diff --git a/src/cols.rs b/src/cols.rs
index 47826d2..349534d 100644
--- a/src/cols.rs
+++ b/src/cols.rs
@@ -43,7 +43,7 @@ impl Cols {
///
/// This makes it possible to add a set while keeping
/// the order of the previous columns, for example
- /// `lfs -c disk+`
+ /// `dysk -c disk+`
pub fn add_set(&mut self, col_set: &[Col]) {
if self.0 == ALL_COLS {
for &col in col_set {
@@ -169,7 +169,7 @@ mod cols_parsing {
fn bad_cols(){
assert_eq!(
"nothing".parse::<Cols>().unwrap_err().to_string(),
- r#""nothing" can't be parsed as a column; use 'lfs --list-cols' to see all column names"#,
+ r#""nothing" can't be parsed as a column; use 'dysk --list-cols' to see all column names"#,
);
}
diff --git a/src/list_cols.rs b/src/list_cols.rs
index 542a6a4..b5da76f 100644
--- a/src/list_cols.rs
+++ b/src/list_cols.rs
@@ -7,13 +7,13 @@ use {
};
static MD: &str = r#"
-The `--cols` launch argument lets you specify the columns of the **lfs** table.
+The `--cols` launch argument lets you specify the columns of the **dysk** table.
-You can give the explicit list of all columns: `lfs -c dev+fs`
+You can give the explicit list of all columns: `dysk -c dev+fs`
-You can add columns to the default ones: `lfs -c +dev+size`
+You can add columns to the default ones: `dysk -c +dev+size`
-Complete syntax at https://dystroy.org/lfs/table
+Complete syntax at https://dystroy.org/dysk/table
|:-:|:-:|:-:|:-
|column | aliases | default | content
diff --git a/src/main.rs b/src/main.rs
index 4957c18..d905bd9 100644
--- a/src/main.rs
+++ b/src/main.rs
@@ -26,7 +26,7 @@ use {
fn main() {
let args: Args = argh::from_env();
if args.version {
- println!("lfs {}", env!("CARGO_PKG_VERSION"));
+ println!("dysk {}", env!("CARGO_PKG_VERSION"));
return;
}
if args.list_cols {
diff --git a/website/README.md b/website/README.md
index 711a38d..3317b2b 100644
--- a/website/README.md
+++ b/website/README.md
@@ -1,5 +1,5 @@
-This website is live at https://dystroy.org/lfs
+This website is live at https://dystroy.org/dysk
It's built using [mkdocs](https://www.mkdocs.org/) (minimal version: 1.0.4).
diff --git a/website/deploy.sh b/website/deploy.sh
index 4aa5705..c111a9a 100755
--- a/website/deploy.sh
+++ b/website/deploy.sh
@@ -1,5 +1,5 @@
mkdocs build
-cp -r site/* ~/dev/www/dystroy/lfs/
+cp -r site/* ~/dev/www/dystroy/dysk/
# deploy on dystroy.org
~/dev/www/dystroy/deploy.sh
diff --git a/website/docs/community.md b/website/docs/community.md
index e0347cc..549c2b1 100644
--- a/website/docs/community.md
+++ b/website/docs/community.md
@@ -1,11 +1,11 @@
-**lfs** is developed by [Denys Séguret](https://twitter.com/DenysSeguret), also known as [Canop](https://github.com/Canop) or [dystroy](https://dystroy.org).
+**dysk** is developed by [Denys Séguret](https://twitter.com/DenysSeguret), also known as [Canop](https://github.com/Canop) or [dystroy](https://dystroy.org).
# Chat
-The best place to chat about lfs, to talk about features or bugs, is the Miaou chat.
+The best place to chat about dysk, to talk about features or bugs, is the Miaou chat.
-* [Rust & lfs room on Miaou](https://miaou.dystroy.org/3490?rust)
+* [Rust & dysk room on Miaou](https://miaou.dystroy.org/3490?rust)
* [French Programmers room on Miaou](https://miaou.dystroy.org/3)
# Issues
@@ -16,11 +16,11 @@ Before posting a new issue, check your problem hasn't already been raised and in
# Licence
-**lfs** is licenced under the [MIT](https://raw.githubusercontent.com/Canop/lfs/master/LICENSE). Enjoy freely.
+**dysk** is licenced under the [MIT](https://raw.githubusercontent.com/Canop/lfs/master/LICENSE). Enjoy freely.
# API
-**lfs** is built on top of [lfs-core](https://docs.rs/lfs-core/).
+**dysk** is built on top of [lfs-core](https://docs.rs/lfs-core/).
If you want to display the same data in your Rust application, consider using this crate directly.
diff --git a/website/docs/css/extra.css b/website/docs/css/extra.css
index ebbb406..4f1500c 100644
--- a/website/docs/css/extra.css
+++ b/website/docs/css/extra.css
@@ -43,7 +43,7 @@ body {
body .col-md-9 p img {
background-color: transparent;
box-shadow: none;
- margin: 50px 0 0 0;
+ /* margin: 50px 0 0 0; */
}
@media (max-width: 800px) {
@@ -63,6 +63,13 @@ p.logo {
background: transparent;
box-shadow: none;
}
+body .bg-secondary {
+ background-color: transparent !important;
+}
+body .card {
+ border: none;
+}
+
h1 {
font-size: 22px;
@@ -91,17 +98,30 @@ h4 {
padding-bottom: 30px;
}
-.navbar {
+body .navbar {
background: var(--top-nav-bg);
border-bottom: 1px solid var(--accent);
+ padding: 0;
}
-
-.navbar-default .navbar-nav > .active > a, .navbar-default .navbar-nav > .active > a:focus {
+html body .navbar-default .navbar-nav > .active > a.nav-link,
+html body .navbar-default .navbar-nav > .active > a.nav-link:focus,
+html body .navbar .navbar-nav > .active > a.nav-link,
+html body .navbar .navbar-nav > .active > a.nav-link:focus {
background-image: linear-gradient(#111,#162020);
color: var(--accent);
}
-.navbar-default .navbar-nav > .open > a, .navbar-default .navbar-nav > .open > a:hover, .navbar-default .navbar-nav > .open > a:focus,
-.navbar-default .navbar-nav > li > a:hover, .navbar-default .navbar-nav > li > a:focus {
+.navbar-default .navbar-nav > .open > a,
+.navbar .navbar-nav > .open > a,
+.navbar-default .navbar-nav > .open > a:hover,
+.navbar .navbar-nav > .open > a:hover,
+.navbar-default .navbar-nav > .open > a:focus,
+.navbar .navbar-nav > .open > a:focus,
+.navbar-default .navbar-nav > li > a:hover,
+.navbar .navbar-nav > li > a:hover,
+.navbar-default .navbar-nav > li > a:hover,
+.navbar .navbar-nav > li > a:hover,
+.navbar-default .navbar-nav > li > a:focus,
+.navbar .navbar-nav > li > a:focus {
background: var(--hovered-menu-bg);
/*color: var(--accent);*/
}
@@ -126,10 +146,16 @@ code {
background: var(--code-bg);
}
-a {
+body a,
+body a.nav-link,
+body .navbar-dark .navbar-nav a,
+body .navbar-dark .navbar-nav a.nav-link
+{
color: var(--sidenav-fg);
}
-a:hover {
+body li.nav-item a:hover,
+body a.nav-link:hover
+{
color: var(--accent);
}
[role="main"] a {
@@ -176,12 +202,15 @@ kbd.b {
background: var(--sidenav-bg);
}
.bs-sidenav.nav li {
- padding-left: 10px;
+ padding-left: 15px;
}
.bs-sidenav.nav li.main {
padding-left: 0px;
}
-.navbar .navbar-brand {
+body .navbar {
+ line-height: 36px;
+}
+body .navbar-brand {
//background: url(../img/logo-white.svg) no-repeat;
// background-position: 5px center;
// background-size: 70px 40px;
@@ -189,7 +218,7 @@ kbd.b {
padding-left: 85px;
color: var(--accent);
/*font-weight: bold;*/
- font-size: 22px;
+ font-size: 24px;
}
.navbar .navbar-brand:hover {
color: var(--accent);
@@ -200,7 +229,11 @@ kbd.b {
}
.bs-sidebar .nav > .active > a,
.bs-sidebar .nav > .active:hover > a,
-.bs-sidebar .nav > .active:focus > a {
+.bs-sidebar .nav > .active:focus > a,
+.bs-sidebar .nav > li > a.active,
+.bs-sidebar .nav > li > a.active:hover,
+.bs-sidebar .nav > li > a.active:focus
+{
font-weight: initial;
background-color: #bed7e632;
border-right: 1px solid;
@@ -208,7 +241,10 @@ kbd.b {
.bs-sidebar .nav > .main.active > a,
.bs-sidebar .nav > .main.active:hover > a,
.bs-sidebar .nav > .main.active:focus > a {
- font-weight: bold;
+ font-weight: normal;
+}
+.bs-sidebar .nav > li > a {
+ font-weight: normal;
}
.table-striped > tbody > tr:nth-of-type(2n+1) {
@@ -259,6 +295,7 @@ body .toc-header {
font-size: 18px;
margin-left: 20px;
padding-bottom: 8px;
+ align-self: start;
}
.admonition.note {
color: var(--text);
diff --git a/website/docs/filters.md b/website/docs/filters.md
index 17f6660..730d72e 100644
--- a/website/docs/filters.md
+++ b/website/docs/filters.md
@@ -19,7 +19,7 @@ Here are the rules of the current heuristics, in order: a filesystem
1. is included when it's remote
1. is excluded when no underlying disk was found
-To see *all* filesystems of your system, do `lfs --all`:
+To see *all* filesystems of your system, do `dysk --all`:
![screen](img/rows-all.png)
@@ -29,7 +29,7 @@ This list can be quite big with virtual file systems, docker use, etc.
If you're only interested in the device on which some file is, give the path as argument.
-For example, for the current device, use `lfs .`:
+For example, for the current device, use `dysk .`:
![screen](img/rows-current.png)
@@ -39,7 +39,7 @@ The `--filter` argument, shortened in `-f`, lets you specify a constraint, or co
A constraint can be related to any [column](../table#all-columns).
-You can for example fetch the filesystems with a given type with `lfs -f 'type=xfs'`.
+You can for example fetch the filesystems with a given type with `dysk -f 'type=xfs'`.
The operators you can apply to a column are the following ones:
@@ -58,7 +58,7 @@ You can combine several column conditions with boolean operators `|` (or), `&` (
For example you may want to select the volumes with not enough space with
```bash
-lfs -f 'free<100G | use>75%'
+dysk -f 'free<100G | use>75%'
```
Examples:
diff --git a/website/docs/img/logo-lfs.png b/website/docs/img/logo-lfs.png
index 51ecef8..3ace601 100644
--- a/website/docs/img/logo-lfs.png
+++ b/website/docs/img/logo-lfs.png
Binary files differ
diff --git a/website/docs/index.md b/website/docs/index.md
index b45880b..a0bc83c 100644
--- a/website/docs/index.md
+++ b/website/docs/index.md
@@ -1,11 +1,9 @@
-<p align=center>
-<img src="img/logo-lfs.png" width=160px>
-</p>
+*dysk was previously known as lfs but was renamed because that name was used by too many things.*
# Purpose
-**lfs** is a linux utility listing your filesystems.
+**dysk** is a linux utility listing your filesystems.
![standard](img/standard.png)
@@ -26,7 +24,7 @@ All sizes are normally based on the current SI recommendations (1M is one millio
# Tables
-The default display of **lfs** is a table, which can be configured with the columns of your choice.
+The default display of **dysk** is a table, which can be configured with the columns of your choice.
![screen](img/c=label+.png)
@@ -36,7 +34,7 @@ The table can also be exported in [CSV](./table#csv).
# JSON
-`lfs --json` outputs the result as JSON which can be used for your own scripts or programs.
+`dysk --json` outputs the result as JSON which can be used for your own scripts or programs.
![screen](img/json-jq-tour.png)
diff --git a/website/docs/install.md b/website/docs/install.md
index 6725af4..9fe3c44 100644
--- a/website/docs/install.md
+++ b/website/docs/install.md
@@ -1,5 +1,5 @@
-**lfs** only works on linux.
+**dysk** only works on linux.
Current version: **<a id=current-version href=../download>download</a>**
<script>
@@ -22,34 +22,34 @@ fetch("../download/version")
# Precompiled binaries
-Binaries are made available at every release in [download](https://dystroy.org/lfs/download).
+Binaries are made available at every release in [download](https://dystroy.org/dysk/download).
Direct links:
Target|Files
-|-
-Android | [aarch64-linux-android](https://dystroy.org/lfs/download/aarch64-linux-android/lfs)
-Linux | [x86_64-linux](https://dystroy.org/lfs/download/x86_64-linux/lfs)
-Linux/musl | [x86_64-unknown-linux-musl](https://dystroy.org/lfs/download/x86_64-unknown-linux-musl/lfs)
-Raspberry | [armv7-unknown-linux-gnueabihf](https://dystroy.org/lfs/download/armv7-unknown-linux-gnueabihf/lfs)
+Android | [aarch64-linux-android](https://dystroy.org/dysk/download/aarch64-linux-android/dysk)
+Linux | [x86_64-linux](https://dystroy.org/dysk/download/x86_64-linux/dysk)
+Linux/musl | [x86_64-unknown-linux-musl](https://dystroy.org/dysk/download/x86_64-unknown-linux-musl/dysk)
+Raspberry | [armv7-unknown-linux-gnueabihf](https://dystroy.org/dysk/download/armv7-unknown-linux-gnueabihf/dysk)
-You may download previous releases on [GitHub releases](https://github.com/Canop/lfs/releases).
+You may download previous releases on [GitHub releases](https://github.com/Canop/dysk/releases).
-When you download executable files, you'll have to ensure the shell can find them. An easy solution is for example to put them in `/usr/local/bin`. You may also have to set them executable using `chmod +x lfs`.
+When you download executable files, you'll have to ensure the shell can find them. An easy solution is for example to put them in `/usr/local/bin`. You may also have to set them executable using `chmod +x dysk`.
# From crates.io
You'll need to have the [Rust development environment](https://www.rustup.rs) installed and up to date.
-Once it's installed, use cargo to install lfs:
+Once it's installed, use cargo to install dysk:
- cargo install lfs
+ cargo install dysk
# From source
You'll need to have the [Rust development environment](https://www.rustup.rs) installed.
-Fetch the [Canop/lfs](https://github.com/Canop/lfs) repository, move to the lfs directory, then run
+Fetch the [Canop/dysk](https://github.com/Canop/lfs) repository, move to the lfs directory, then run
```bash
cargo install --path .
@@ -64,9 +64,12 @@ Those packages are maintained by third parties and may be less up to date.
## Arch Linux
-**lfs** can be installed from the [community repository](https://archlinux.org/packages/community/x86_64/lfs/):
+(with its previous name, "lfs")
+
+**dysk** can be installed from the [community repository](https://archlinux.org/packages/community/x86_64/lfs/):
```
pacman -S lfs
```
+
diff --git a/website/docs/json.md b/website/docs/json.md
index af93c52..a14c9dd 100644
--- a/website/docs/json.md
+++ b/website/docs/json.md
@@ -1,5 +1,5 @@
-With `lfs --json` (shortened in `lfs -j`) you get a JSON structure that can be used in other programs.
+With `dysk --json` (shortened in `dysk -j`) you get a JSON structure that can be used in other programs.
# JSON output
@@ -8,7 +8,7 @@ The normal output is an array of all filesystem matching the filter.
In order to make a sample fitting this site, I extracted the first filesystem with
```bash
-lfs -j | jq '.[0]' > disk.json
+dysk -j | jq '.[0]' > disk.json
```
Here it is:
@@ -61,11 +61,11 @@ Note that fields may be *added* in any version.
As for the table view, the JSON is by default limited to "normal" storage devices.
-You can get the complete list with `lfs --json --all`.
+You can get the complete list with `dysk --json --all`.
# Pipe
-The output of `lfs -j` can be piped into another program.
+The output of `dysk -j` can be piped into another program.
You can for example use [jq](https://stedolan.github.io/jq/) to filter or extract data:
diff --git a/website/docs/table.md b/website/docs/table.md
index 4079114..f5744c9 100644
--- a/website/docs/table.md
+++ b/website/docs/table.md
@@ -1,10 +1,10 @@
-The standard output of lfs is a table with a default set of columns and only the "normal looking" filesystems.
+The standard output of dysk is a table with a default set of columns and only the "normal looking" filesystems.
You can modify it easily.
# Columns
-You can run `lfs --list-cols` for the list of all columns.
+You can run `dysk --list-cols` for the list of all columns.
## All columns
@@ -44,30 +44,30 @@ With `-c all`, you may see all available columns, but that's normally too much f
The most obvious use of the `--cols` argument is the explicit definition of the columns to display.
-For example `lfs -c label+use+size+disk+mount` will show the `label`, `use`, `size`, `disk`, and `mount` columns, in that order:
+For example `dysk -c label+use+size+disk+mount` will show the `label`, `use`, `size`, `disk`, and `mount` columns, in that order:
![screen](img/c=label+use+size+disk+mount.png)
All the default columns (see [table above](#columns)) can be inserted with just `default`.
-Here's adding the label at the start and the device id at the end, with `lfs -c label+default+dev`:
+Here's adding the label at the start and the device id at the end, with `dysk -c label+default+dev`:
![screen](img/c=label+default+dev.png)
If the `--cols` argument starts or ends with `+` or `-`, the `default` set of columns is implied.
-To add the device id and the share of inodes used to the default columns, you do `lfs -c +dev+inodes`:
+To add the device id and the share of inodes used to the default columns, you do `dysk -c +dev+inodes`:
![screen](img/c=+dev+inodes.png)
-To preprend the `label` column before the default ones, use `lfs -c label+`:
+To preprend the `label` column before the default ones, use `dysk -c label+`:
![screen](img/c=label+.png)
The `-` sign removes columns.
And adding an already present column moves it to the end (there's never duplicates).
-Here's removing the `fs` column and moving the `type` column to the end, with `lfs -c -fs+type`:
+Here's removing the `fs` column and moving the `type` column to the end, with `dysk -c -fs+type`:
![screen](img/c=-fs+type.png)
@@ -76,7 +76,7 @@ Here's removing the `fs` column and moving the `type` column to the end, with `l
With the `--sort` launch argument, shortened as `-s`, you can specify the order of displayed rows.
-The argument's value must be either a column name, for example `lfs -s dev`, or a column name and a direction, for example `lfs --sort size-desc`.
+The argument's value must be either a column name, for example `dysk -s dev`, or a column name and a direction, for example `dysk --sort size-desc`.
The `desc` and `asc` directions can be abbreviated into `d` and `a`.
@@ -90,10 +90,10 @@ Or sorting on the remaining free space, in descending order:
# CSV
-With the `--csv` argument, you can ask lfs to output the table in CSV:
+With the `--csv` argument, you can ask dysk to output the table in CSV:
```bash
-lfs --csv > mounts.csv
+dysk --csv > mounts.csv
```
You may choose the separator with the `--csv-separator` argument.
@@ -101,7 +101,7 @@ You may choose the separator with the `--csv-separator` argument.
Filters, sorting, and column selection work the same than for standard tables so you may do this:
```bash
-lfs --csv -f 'size>100G' -c remote+default+inodes > mounts.csv
+dysk --csv -f 'size>100G' -c remote+default+inodes > mounts.csv
```
which would give something like this:
diff --git a/website/mkdocs.yml b/website/mkdocs.yml
index 6c728bf..07a1d4e 100644
--- a/website/mkdocs.yml
+++ b/website/mkdocs.yml
@@ -1,6 +1,6 @@
-site_name: lfs
-site_description: 'lfs, like df but better'
-site_url: https://dystroy.org/lfs
+site_name: dysk
+site_description: 'dysk, like df but better'
+site_url: https://dystroy.org/dysk
repo_url: https://github.com/Canop/lfs
edit_uri: ''
diff --git a/release.sh b/release.sh
index 7a586cd..bd04c75 100755
--- a/release.sh
+++ b/release.sh
@@ -1,4 +1,4 @@
# build a new release of lfs for distribution
#
# WARNING: this is not intented for normal usage but
# for the official release. It involves a heavy tool
@@ -24,16 +24,16 @@ mkdir build
./compile-all-targets.sh
# add the readme and changelog in the build directory
-echo "This is lfs. More info and installation instructions on https://github.com/Canop/lfs" > build/README.md
+echo "This is dysk. More info and installation instructions on https://github.com/Canop/dysk" > build/README.md
cp CHANGELOG.md build
# publish version number
echo "$version" > build/version
# prepare the release archive
-rm lfs_*.zip
-zip -r "lfs_$version.zip" build/*
+rm dysk_*.zip
+zip -r "dysk_$version.zip" build/*
# copy it to releases folder
mkdir releases
-cp "lfs_$version.zip" releases
+cp "dysk_$version.zip" releases
@@ -1,4 +1,4 @@
-# build a new release of lfs for distribution
+# build a new release of dysk for distribution
#
# WARNING: this is not intented for normal usage but